@@ -1,8 +1,5 @@
 package Sys::Sendfile;
-{
-  $Sys::Sendfile::VERSION = '0.12';
-}
-
+$Sys::Sendfile::VERSION = '0.13';
 # This software is copyright (c) 2008, 2009 by Leon Timmermans <leont@cpan.org>.
 #
 # This is free software; you can redistribute it and/or modify it under
@@ -33,7 +30,7 @@ Sys::Sendfile - Zero-copy data transfer
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -46,9 +43,9 @@ Sys::Sendfile provides access to your operating system's C<sendfile> facility. I
 
 =head1 FUNCTIONS
 
-=head2 sendfile $out, $in, $count
+=head2 sendfile $out, $in, $count, $offset
 
-This function sends up to C<$count> B<bytes> from C<$in> to C<$out>. If $count isn't given, it will try send all remaining bytes in $in, but on some operating systems sending only part of the bytes is a possible result. C<$in> and C<$out> can be a bareword, constant, scalar expression, typeglob, or a reference to a typeglob. It returns the number of bytes actually sent. On error, C<$!> is set appropriately and it returns undef. This function is exported by default.
+This function sends up to C<$count> B<bytes> starting from C<$offset> from C<$in> to C<$out>. If $count isn't given, it will try send all remaining bytes in $in, but on some operating systems sending only part of the bytes is a possible result. If C<$offset> isn't given, the function will get current offset of C<$in> (by calling lseek) and pass this information to underlying sendfile syscall. C<$in> and C<$out> can be a bareword, constant, scalar expression, typeglob, or a reference to a typeglob. It returns the number of bytes actually sent. On error, C<$!> is set appropriately and it returns undef. This function is exported by default.
 
 =head1 BUGS AND LIMITATIONS
 
